@@ -498,4 +498,93 @@ unique_identifier <- function(x, fields, start_from = 1L){
     id <- id - 1L + as.integer(start_from)
   }
   id
+}
+
+
+#' @title Concatenate text of each group of data together
+#' @description This function is similar to \code{\link{paste}}
+#' but works on a data.frame, hence paste.data.frame. 
+#' It concatenates text belonging to groups of data together in one string. 
+#' The function is the inverse operation of \code{\link{strsplit.data.frame}}.
+#' @param data a data.frame or data.table
+#' @param term a string with a column name or a character vector of column names from \code{data} which you want to concatenate together using \code{\link{paste}}
+#' @param group a string with a column name or a character vector of column names from \code{data} indicating identifiers of groups. 
+#' The text in \code{term} will be concatenated by group.
+#' @param collapse a character string that you want to use to collapse the text data together. 
+#' Defaults to a single space.
+#' @return A data.frame with 1 row per group containing the columns from \code{group} and \code{term} 
+#' where all the text in \code{term} for each group will be \code{\link{paste}-d} together, separated by the \code{collapse} argument.
+#' @seealso \code{\link{strsplit.data.frame}}, \code{\link{paste}}
+#' @export
+#' @examples 
+#' data(brussels_reviews_anno, package = "udpipe")
+#' head(brussels_reviews_anno)
+#' x <- paste.data.frame(brussels_reviews_anno, 
+#'                       term = "lemma", 
+#'                       group = c("doc_id", "sentence_id"))
+#' str(x)
+#' x <- paste.data.frame(brussels_reviews_anno, 
+#'                       term = c("lemma", "token"), 
+#'                       group = c("doc_id", "sentence_id"), 
+#'                       collapse = "-")
+#' str(x)                       
+paste.data.frame <- function(data, term, group, collapse=" "){
+  .SDcols <- .SD <- NULL
+  stopifnot(inherits(data, "data.frame"))
+  stopifnot(inherits(term, "character"))
+  stopifnot(inherits(group, "character"))
+  stopifnot(all(c(term, group) %in% colnames(data)))
+  if(inherits(data, "data.table")){
+  }else{
+    x <- data.table::as.data.table(data[, c(term, group)])  
+  }
+  x <- x[, lapply(.SD, FUN=function(x) paste(x, collapse = collapse)), by = group, .SDcols = term]
+  x <- data.table::setDF(x)
+  x
+}
+
+#' @title Obtain a tokenised data frame by splitting text alongside a regular expression 
+#' @description Obtain a tokenised data frame by splitting text alongside a regular expression. 
+#' This is the inverse operation of \code{\link{paste.data.frame}}.
+#' @param data a data.frame or data.table
+#' @param term a character with a column name from \code{data} which you want to split into tokens
+#' @param group a string with a column name or a character vector of column names from \code{data} indicating identifiers of groups. 
+#' The text in \code{term} will be split into tokens by group.
+#' @param split a regular expression indicating how to split the \code{term} column. 
+#' Defaults to splitting by spaces, punctuation symbols or digits. This will be passed on to \code{\link{strsplit}}.
+#' @return A tokenised data frame containing one row per token.\cr
+#' This data.frame has the columns from \code{group} and \code{term} where the text in column \code{term}
+#' will be split by the provided regular expression into tokens. 
+#' @seealso \code{\link{paste.data.frame}}, \code{\link{strsplit}}
+#' @export
+#' @examples 
+#' data(brussels_reviews, package = "udpipe")
+#' x <- strsplit.data.frame(brussels_reviews, term = "feedback", group = "id")
+#' head(x)
+#' x <- strsplit.data.frame(brussels_reviews, 
+#'                          term = c("feedback"), 
+#'                          group = c("listing_id", "language"))
+#' head(x)                          
+strsplit.data.frame <- function(data, term, group, split = "[[:space:][:punct:][:digit:]]+"){
+  .SDcols <- .SD <- NULL
+  stopifnot(inherits(data, "data.frame"))
+  stopifnot(inherits(term, "character"))
+  stopifnot(inherits(group, "character"))
+  stopifnot(all(c(term, group) %in% colnames(data)))
+  if(length(term) > 1){
+    warning("strsplit.data.frame is not intended to be called with several columns in term")
+  }
+  if(inherits(data, "data.table")){
+  }else{
+    x <- data.table::as.data.table(data[, c(term, group)])  
+  }
+  x <- x[, lapply(.SD, FUN=function(txt){
+    terms <- unlist(strsplit(txt, split = split))
+    terms <- as.character(terms)
+    terms <- terms[!is.na(terms)]
+    terms <- terms[nchar(terms) > 0]
+    terms
+  }), by = group, .SDcols = term]
+  x <- data.table::setDF(x)
+  x
 }
\ No newline at end of file
