@@ -108,3 +108,6 @@ y <- subset(y, term1 < term2 & abs(cooc) > 0.2)
 y <- y[order(abs(y$cooc), decreasing = TRUE), ]
 head(y)
 
+## ---- results='hide', echo=FALSE------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+invisible(file.remove(c("spanish-gsd-ud-2.3-181115.udpipe")))
+
